<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library VT Blogging Pro
 */

function customizer_library_vt_blogging_pro_options() {

	// Theme defaults
	$primary_color = '#eb5424';
	$secondary_color = '#ffffff';
	$tertiary_color = '#65aba7';
	
	$body_font_color = '#636161';
	$heading_font_color = '#3a3a3a';
	
	$submenu_link_color = '#222222';
    $header_bg_color = '#343e47';
    $footer_bg_color = '#343e47';
    $footer_text_color = '#9f9f9f';
	
	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;
	
	/**-----------------
	 * Theme Settings
	 -----------------*/
    $panel = 'vt-panel-layout';

    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Theme Settings', 'vt-blogging-pro' ),
        'priority' => '30'
    );

    $section = 'title_tagline';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Site Identity', 'vt-blogging-pro' ),
        'priority' => '10',
		'panel' => $panel
	);
	
    $options['logo-height-size'] = array(
        'id' => 'logo-height-size',
        'label'   => __( 'Logo max-height', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 67,
        'description' => __( 'Default: 67', 'vt-blogging-pro' ),
		'priority' => '8',
    );
    $options['logo-max-width'] = array(
        'id' => 'logo-max-width',
        'label'   => __( 'Logo max-width', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 190,
        'description' => __( 'Default: 190', 'vt-blogging-pro' ),
		'priority' => '8',
    );
	
    $options['disable_site_desc'] = array(
        'id' => 'disable_site_desc',
        'label'   => __( 'Disable Site Description', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
		'default' => 0,
		'priority' => '11',
    );
	
	// Header Settings
    $section = 'vt-site-layout-section-header';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Header', 'vt-blogging-pro' ),
        'priority' => '20',
		'panel' => $panel
    );

    $options['sticky-header'] = array(
        'id' => 'sticky-header',
        'label'   => __( 'Enable Sticky Header', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	
	$options['header-search'] = array(
        'id' => 'header-search',
        'label'   => __( 'Enable Header Searchform', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	
	if (class_exists( 'woocommerce' )) {
        $options['woo-cart-button'] = array(
            'id' => 'woo-cart-button',
            'label'   => __( 'Display WooCommerce Cart', 'vt-blogging-pro' ),
            'section' => $section,
            'type'    => 'ios',
            'default' => 1,
        );
	}
	
	// Layout Settings
	$section = 'vt-site-layout-setting';

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Layout Settings', 'vt-blogging-pro' ),
		'priority' => '30',
		'panel' => $panel
	);
    
    $choices = array(
		'1000' => __('1000px', 'vt-blogging-pro'),
		'1050' => __('1050px', 'vt-blogging-pro'),
		'1100' => __('1100px', 'vt-blogging-pro'),
		'1150' => __('1150px', 'vt-blogging-pro'),
		'1200' => __('1200px', 'vt-blogging-pro'),
    );
    $options['site_container'] = array(
        'id' => 'site_container',
        'label'   => __( 'Main Container Width', 'vt-blogging-pro' ),
		'description' => __( 'Layout width size. Default: 1000 <code>px</code>', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '1000'
    );
	
	$choices = array(
		'choice-1' => __('Responsive Layout', 'vt-blogging-pro'),
		'choice-2' => __('Fixed Layout', 'vt-blogging-pro'),
    );
	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Site Layout', 'vt-blogging-pro' ),
		'section' => $section,
		'type'    => 'radio',
        'choices' => $choices,
		'default' => 'choice-1'
	);
	
    $choices = array(
		'layout-1' => __('List Layout - Left Thumbnail', 'vt-blogging-pro'),
		'layout-2' => __('List Layout - Right Thumbnail', 'vt-blogging-pro'),
		'layout-3' => __('List Layout 3', 'vt-blogging-pro'),
		'1stfull' => __('First Fullpost + List Layout', 'vt-blogging-pro'),
		'standard-list' => __('First Standard + List Layout', 'vt-blogging-pro'),
		'standard' => __('Standard Blog Layout', 'vt-blogging-pro'),
    );
    $options['blog-page-layout'] = array(
        'id' => 'blog-page-layout',
        'label'   => __( 'Blog Page Layout', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'layout-1'
    );
	
	$choices = array(
		'layout-1' => __('List Layout - Left Thumbnail', 'vt-blogging-pro'),
		'layout-2' => __('List Layout - Right Thumbnail', 'vt-blogging-pro'),
		'layout-3' => __('List Layout 3', 'vt-blogging-pro'),
		'1stfull' => __('First Fullpost + List Layout', 'vt-blogging-pro'),
		'standard-list' => __('First Standard + List Layout', 'vt-blogging-pro'),
		'standard' => __('Standard Blog Layout', 'vt-blogging-pro'),
    );
    $options['archive-page-layout'] = array(
        'id' => 'archive-page-layout',
        'label'   => __( 'Archive Page Layout', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'layout-1'
    );
	
	$choices = array(
		'1' => __('Enable Animation', 'vt-blogging-pro'),
		'2' => __('Disable Animation', 'vt-blogging-pro'),
    );
    $options['animate_enable'] = array(
        'id' => 'animate_enable',
        'label'   => __( 'Animation', 'vt-blogging-pro' ),
		'description' => __( 'This setting will showing animations for blog posts.', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
		'choices' => $choices,
        'default' => '1'
    );
	
	// Featured Slider
	$section = 'featured-area';

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Featured Slider', 'vt-blogging-pro' ),
		'priority' => '40',
		'panel' => $panel
	);
	
	$options['featured-slider-on'] = array(
		'id' => 'featured-slider-on',
		'label'   => __( 'Enable Featured Slider', 'vt-blogging-pro' ),
		'section' => $section,
		'type'    => 'ios',
		'default' => 1,
		'priority' => '5'
	);
    $options['slider_featured_id'] = array(
        'id' => 'slider_featured_id',
		'label'   => __( 'Or enter Post/Page IDs', 'vt-blogging-pro' ),
		'description' => __( 'Enter the ID\'s of the post/page you\'d like to display to Slider, enter only the ID\'s with separated by a comma (,)<br /><code>Eg: "13, 17, 19"</code><br /><br />More detail: <a target="_blank" href="https://volthemes.com/docs/vt-blogging-pro-documentation/#featured-area">Documentation</a>.', 'vt-blogging-pro' ),
        'section' => $section,
		'type'    => 'text',
		'default' => ''
    );
    $options['featured-slider-slides'] = array(
        'id' => 'featured-slider-slides',
        'label'   => __( 'Amount of Slides', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 5,
    );
    $options['featured-slider-category'] = array(
        'id' => 'featured-slider-category',
        'label'   => __( 'Display Post Category', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	$options['featured-slider-date'] = array(
        'id' => 'featured-slider-date',
        'label'   => __( 'Display Post Date', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	$options['featured-slider-share'] = array(
        'id' => 'featured-slider-share',
        'label'   => __( 'Display Social Share', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	$options['slider_content'] = array(
        'id' => 'slider_content',
        'label'   => __( 'Display Post Excerpt', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	$options['featured-slider-readmore'] = array(
        'id' => 'featured-slider-readmore',
        'label'   => __( 'Display Read More Button', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	$options['slider_cat_color'] = array(
		'id' => 'slider_cat_color',
		'label'   => __( 'Category Title Color', 'vt-blogging-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $secondary_color,
	);
	$options['slider_title_color'] = array(
		'id' => 'slider_title_color',
		'label'   => __( 'Title Color', 'vt-blogging-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $secondary_color,
	);
	$options['slider_title_hover_color'] = array(
		'id' => 'slider_title_hover_color',
		'label'   => __( 'Title Hover Color', 'vt-blogging-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $secondary_color,
	);
	$options['slider_read_more_color'] = array(
		'id' => 'slider_read_more_color',
		'label'   => __( 'Read More Text Color', 'vt-blogging-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $secondary_color,
	);
	$options['slider_arrow_color'] = array(
		'id' => 'slider_arrow_color',
		'label'   => __( 'Arrow Color', 'vt-blogging-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $secondary_color,
	);
	
	// Blog Layout
	$section = 'vt-site-layout-section-site';

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Blog Settings', 'vt-blogging-pro' ),
		'priority' => '50',
		'panel' => $panel
	);
    
	$options['blog_meta_setting'] = array(
        'id' => 'blog_meta_setting',
        'label'   => __( 'Display Settings', 'vt-blogging-pro' ),
		'description' => __( 'Choose whether to display Post Meta/ Featured Images in the blog feed.', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
    );
    $options['blog_post_meta'] = array(
        'id' => 'blog_post_meta',
        'label'   => __( 'Display Post Meta', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
    $options['blog_post_thumb'] = array(
        'id' => 'blog_post_thumb',
        'label'   => __( 'Display Featured Images', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	
	$options['entry-excerpt-length'] = array(
		'id' => 'entry-excerpt-length',
		'label'   => __( 'Excerpt Length', 'vt-blogging-pro' ),
		'description' => __( 'Number of words to show on excerpt. Default: 38', 'vt-blogging-pro' ),
		'section' => $section,
        'type'    => 'number',
        'default' => 38
	);
	
    $options['vt-blog-cats'] = array(
        'id' => 'vt-blog-cats',
        'label'   => __( 'Exclude Blog Categories', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'description' => __( 'Enter the ID\'s of the post categories you\'d like to EXCLUDE from the Blog, enter only the ID\'s with a minus sign (-) before them, separated by a comma (,)<br /><code>Eg: "-13, -17, -19"</code><br /><br />If you enter the ID\'s without the minus then it\'ll show ONLY posts in those categories.<br /><br />Get the ID at <b>Posts -> Categories</b>.', 'vt-blogging-pro' )
    );
	
	// Single Posts
    $section = 'vt-blog-section-post';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Single Posts', 'vt-blogging-pro' ),
        'priority' => '60',
        'panel' => $panel
    );

	$options['single_meta_setting'] = array(
        'id' => 'single_meta_setting',
        'label'   => __( 'Display Settings', 'vt-blogging-pro' ),
		'description' => __( 'Choose whether to display Post Meta/Tags, etc. This applies to all Single posts.', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
    );

    $options['single-meta-on'] = array(
        'id' => 'single-meta-on',
        'label'   => __( 'Display Post Meta Info', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
    $options['single-featured-on'] = array(
        'id' => 'single-featured-on',
        'label'   => __( 'Display Featured Images', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
    $options['single-tags-on'] = array(
        'id' => 'single-tags-on',
        'label'   => __( 'Display Posts Tags', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
    $options['entry-footer-on'] = array(
        'id' => 'entry-footer-on',
        'label'   => __( 'Display Entry Footer', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	$options['related-posts-on'] = array(
        'id' => 'related-posts-on',
        'label'   => __( 'Display Related Posts', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	
	// Sidebar
    $section = 'vt-blog-section-sidebar';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Sidebar', 'vt-blogging-pro' ),
        'priority' => '70',
        'panel' => $panel
    );

	$imagepath =  '%s/customizer/customizer-library/images/';
	
	$image_choices = array(
		'left'  => array( 
			'url' => $imagepath .'sidebar-left.png', 
			'label' => esc_html__( 'Left Sidebar', 'vt-blogging-pro' ),
		),
		'right' => array( 
			'url' => $imagepath .'sidebar-right.png', 
			'label' => esc_html__( 'Right Sidebar', 'vt-blogging-pro' ),
		),
	);
	$options['sidebar_position'] = array(
		'id'  => 'sidebar_position',
		'label'   => esc_html__( 'Sidebar Position', 'vt-blogging-pro' ),
		'section' => $section,
        'type'    => 'radio-image',
		'choices' => $image_choices,
		'default' => 'right'
	);
	
    $options['sticky_sidebar'] = array(
        'id' => 'sticky_sidebar',
        'label'   => __( 'Enable Sticky Sidebar', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	
	// Post Share Settings
    $section = 'vt-blog-section-share';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Social Share', 'vt-blogging-pro' ),
        'priority' => '80',
        'panel' => $panel
    );

    $options['social-share-fb'] = array(
        'id' => 'social-share-fb',
        'label'   => __( 'Display Facebook Share', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
    $options['social-share-tw'] = array(
        'id' => 'social-share-tw',
        'label'   => __( 'Display Twitter Share', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
    $options['social-share-pin'] = array(
        'id' => 'social-share-pin',
        'label'   => __( 'Display Pinterest Share', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	$options['social-share-in'] = array(
        'id' => 'social-share-in',
        'label'   => __( 'Display Linkedin Share', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 0,
    );
	$options['social-share-mail'] = array(
        'id' => 'social-share-mail',
        'label'   => __( 'Display Email Share', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 0,
    );
	$options['social-share-vk'] = array(
        'id' => 'social-share-vk',
        'label'   => __( 'Display  VK Share', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 0,
    );
	
	// Footer Settings
    $section = 'vt-site-layout-section-footer';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Footer', 'vt-blogging-pro' ),
        'priority' => '90',
		'panel' => $panel
    );
	
	$imagepath =  '%s/customizer/customizer-library/images/';
	
	$image_choices = array(
		'2'  => array( 
			'url' => $imagepath .'footer-2-col.png', 
			'label' => esc_html__( '2 Column', 'vt-blogging-pro' ),
		),
		'3' => array( 
			'url' => $imagepath .'footer-3-col.png', 
			'label' => esc_html__( '3 Column', 'vt-blogging-pro' ),
		),
		'4' => array( 
			'url' => $imagepath .'footer-4-col.png', 
			'label' => esc_html__( '4 Column', 'vt-blogging-pro' ),
		),
	);
	$options['footer-widget-column'] = array(
		'id'  => 'footer-widget-column',
		'label'   => esc_html__( 'Footer Widget Column', 'vt-blogging-pro' ),
		'section' => $section,
        'type'    => 'radio-image',
		'choices' => $image_choices,
		'default' => '4'
	);
	
	$options['footer-copyright'] = array(
        'id' => 'footer-copyright',
        'label'   => __( 'Footer Copyright Text', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'richedit',
        'default' => ''
    );

    $options['footer-menu-on'] = array(
        'id' => 'footer-menu-on',
        'label'   => __( 'Display Footer Menu', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );
	
	$options['backtotop-button'] = array(
        'id' => 'backtotop-button',
        'label'   => __( 'Display Backtotop Button', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'ios',
        'default' => 1,
    );

    // WooCommerce style Layout
	if (class_exists( 'woocommerce' )) {
        $section = 'vt-site-layout-section-woocommerce';

        $sections[] = array(
            'id' => $section,
            'title' => __( 'WooCommerce', 'vt-blogging-pro' ),
            'priority' => '90',
            'panel' => $panel
        );
        $options['display-wc-page-title'] = array(
            'id' => 'display-wc-page-title',
            'label'   => __( 'Display "Shop" Page Title', 'vt-blogging-pro' ),
            'section' => $section,
            'type'    => 'ios',
            'default' => 1,
        );
		$options['display-wc-sidebar'] = array(
            'id' => 'display-wc-sidebar',
            'label'   => __( 'Display Shop Sidebar', 'vt-blogging-pro' ),
            'section' => $section,
            'type'    => 'ios',
            'default' => 1,
        );
		$options['shop-limit-post'] = array(
			'id' => 'shop-limit-post',
			'label'   => __( 'Shop Posts Product per page', 'vt-blogging-pro' ),
			'section' => $section,
			'type'    => 'number',
			'default' => 12,
		);


	}

	/**-----------------
	 * Color Settings
	 -----------------*/
    $panel = 'vt-colors-settings';

    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Color Settings', 'vt-blogging-pro' ),
        'priority' => '50'
    );
    
    // Colors
    $section = 'colors';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Default Colors', 'vt-blogging-pro' ),
        'priority' => '10',
        'panel' => $panel
    );
    $options['body-font-color'] = array(
        'id' => 'body-font-color',
        'label'   => __( 'Body Font Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#414141'
    );
    $options['heading-font-color'] = array(
        'id' => 'heading-font-color',
        'label'   => __( 'Heading Font Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $heading_font_color,
    );
	if (class_exists( 'woocommerce' )) {
        $options['wc-product-title-color'] = array(
            'id' => 'wc-product-title-color',
            'label'   => __( 'WooCommerce Product Title Color', 'vt-blogging-pro' ),
            'section' => $section,
            'type'    => 'color',
            'default' => $heading_font_color,
        );
    }
    $options['link-color'] = array(
        'id' => 'link-color',
        'label'   => __( 'Link Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#444444',
    );
	$options['link-color-hover'] = array(
        'id' => 'link-color-hover',
        'label'   => __( 'Link Hover Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#222222',
    );

	// Header
    $section = 'vt-panel-colors-section-header';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Header', 'vt-blogging-pro' ),
        'priority' => '10',
        'panel' => $panel
    );
    $options['header-bg-color'] = array(
        'id' => 'header-bg-color',
        'label'   => __( 'Background Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $header_bg_color,
    );
    $options['header-bg-opacity'] = array(
        'id' => 'header-bg-opacity',
        'label'   => __( 'Header Opacity', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'range',
        'input_attrs' => array(
            'min'   => 0,
            'max'   => 99,
            'step'  => 1,
        ),
        'default' => 99
    );

	// Header Icon
    $options['header-icon-color'] = array(
        'id' => 'header-icon-color',
        'label'   => __( 'Header Icon Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => $secondary_color,
    );
	
	$options['header-icon-hover-color'] = array(
        'id' => 'header-icon-hover-color',
        'label'   => __( 'Header Icon Hover Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => '#bbbbbb',
    );
	
	// Header Search
    $options['header-search-bg-color'] = array(
        'id' => 'header-search-bg-color',
        'label'   => __( 'Header Search Background Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => '#3c4852',
    );
	
	// Navigation
    $section = 'vt-panel-colors-section-nav';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Navigation', 'vt-blogging-pro' ),
        'priority' => '10',
        'panel' => $panel
    );
    
    $options['header-menu-bg-color'] = array(
        'id' => 'header-menu-bg-color',
        'label'   => __( 'Menu Background Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $tertiary_color,
    );
    $options['header-menu-color'] = array(
        'id' => 'header-menu-color',
        'label'   => __( 'Menu Link Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $secondary_color,
    );
	$options['header-menu-hover-color'] = array(
        'id' => 'header-menu-hover-color',
        'label'   => __( 'Menu Link Hover Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $secondary_color,
    );
	$options['header-menu-border-color'] = array(
        'id' => 'header-menu-border-color',
        'label'   => __( 'Menu Border Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $primary_color,
    );
    $options['header-submenu-bg-color'] = array(
        'id' => 'header-submenu-bg-color',
        'label'   => __( 'Sub Menu Background Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $secondary_color,
    );
	$options['header-submenu-color'] = array(
        'id' => 'header-submenu-color',
        'label'   => __( 'Submenu Link Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $submenu_link_color,
    );
	$options['header-submenu-hover-color'] = array(
        'id' => 'header-submenu-hover-color',
        'label'   => __( 'Submenu Link Hover Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $submenu_link_color,
    );
	
	// Widgets
    $section = 'vt-panel-colors-section-widgets';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Widgets', 'vt-blogging-pro' ),
        'priority' => '10',
        'panel' => $panel
    );
	$options['widget-sidebar-title'] = array(
        'id' => 'widget-sidebar-title',
        'label'   => __( 'Sidebar Widget Title Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => '#333333'
    );
	$options['widget-sidebar-link'] = array(
        'id' => 'widget-sidebar-link',
        'label'   => __( 'Sidebar Widget Link Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => '#333333'
    );
	$options['widget-sidebar-hover-link'] = array(
        'id' => 'widget-sidebar-hover-link',
        'label'   => __( 'Sidebar Widget Link Hover Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => $primary_color,
    );
	$options['widget-footer-title'] = array(
        'id' => 'widget-footer-title',
        'label'   => __( 'Footer Widget Title Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => $secondary_color,
    );
	$options['widget-footer-link'] = array(
        'id' => 'widget-footer-link',
        'label'   => __( 'Footer Widget Link Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => '#9f9f9f'
    );
	$options['widget-footer-hover-link'] = array(
        'id' => 'widget-footer-hover-link',
        'label'   => __( 'Footer Widget Link Hover Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $secondary_color,
    );
	$options['widget-border-color'] = array(
        'id' => 'widget-border-color',
        'label'   => __( 'Widget Title Border Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $primary_color,
    );
	
	// Pagination
    $section = 'vt-panel-colors-section-pagination';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Pagination', 'vt-blogging-pro' ),
        'priority' => '10',
        'panel' => $panel
    );
    $options['navigation-pagination'] = array(
        'id' => 'navigation-pagination',
        'label'   => __( 'Pagination Background Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => '#e8edf3'
    );
	$options['navi-text-color'] = array(
        'id' => 'navi-text-color',
        'label'   => __( 'Pagination Text & Number Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => '#222222'
    );
	$options['navi-current-bg'] = array(
        'id' => 'navi-current-bg',
        'label'   => __( '"Current & Hover" Background Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => $primary_color,
    );
	$options['navi-current-text'] = array(
        'id' => 'navi-current-text',
        'label'   => __( '"Current & Hover" Text Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => $secondary_color
    );	
	
	// Footer
    $section = 'vt-panel-colors-section-footer';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Footer', 'vt-blogging-pro' ),
        'priority' => '10',
        'panel' => $panel
    );
    $options['footer-bg-color'] = array(
        'id' => 'footer-bg-color',
        'label'   => __( 'Background Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $footer_bg_color,
    );
    $options['footer-text-color'] = array(
        'id' => 'footer-text-color',
        'label'   => __( 'Footer Text Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $footer_text_color,
    );
	$options['footer-link-color'] = array(
        'id' => 'footer-link-color',
        'label'   => __( 'Footer Link Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#bbbbbb'
    );
	$options['footer-link-hover-color'] = array(
        'id' => 'footer-link-hover-color',
        'label'   => __( 'Footer Link Hover Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => $secondary_color,
    );
	
	// Site Bottom
    $options['footer-sitebottom-bg-color'] = array(
        'id' => 'footer-sitebottom-bg-color',
        'label'   => __( 'Site Bottom Bg Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#262f3c'
    );
    $options['footer-sitebottom-font-color'] = array(
        'id' => 'footer-sitebottom-font-color',
        'label'   => __( 'Site Bottom Text Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => '#6a6a6a'
    );
	$options['footer-sitebottom-link-color'] = array(
        'id' => 'footer-sitebottom-link-color',
        'label'   => __( 'Site Bottom Link Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
        'default' => '#888888'
    );
	$options['footer-sitebottom-hover-color'] = array(
        'id' => 'footer-sitebottom-hover-color',
        'label'   => __( 'Site Bottom Link Hover Color', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'color',
		'default' => '#888888'
    );
    
	/**-----------------
	 * Font Options
	 -----------------*/
    $panel = 'vt-panel-font-settings';

    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Font Settings', 'vt-blogging-pro' ),
        'priority' => '60'
    );

	// Site Title 
    $section = 'typography-section';
    $font_choices = customizer_library_get_font_choices();

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Site Title', 'vt-blogging-pro' ),
		'description' => __( 'Do not use <code>px</code> on Font settings <span class="dashicons dashicons-info"></span>', 'vt-blogging-pro' ),
        'priority' => '20',
        'panel' => $panel
    );

    $options['site-title-font'] = array(
        'id' => 'site-title-font',
        'label'   => __( 'Google Font Name', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Open Sans',
        'description' => __( 'Default: Open Sans', 'vt-blogging-pro' )
    );
    $choices = array(
        '100' => __( 'Thin (100)', 'vt-blogging-pro' ),
        '200' => __( 'Extra Light (200)', 'vt-blogging-pro' ),
        '300' => __( 'Light (300)', 'vt-blogging-pro' ),
        '400' => __( 'Normal (400)', 'vt-blogging-pro' ),
        '500' => __( 'Medium (500)', 'vt-blogging-pro' ),
        '600' => __( 'Semi-Bold (600)', 'vt-blogging-pro' ),
        '700' => __( 'Bold (700)', 'vt-blogging-pro' ),
        '800' => __( 'Extra Bold (800)', 'vt-blogging-pro' ),
        '900' => __( 'Ultra Bold (900)', 'vt-blogging-pro' )
    );
	$options['site-title-font-weight'] = array(
        'id' => 'site-title-font-weight',
        'label'   => __( 'Font Weight', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '400',
        'description' => __( 'Default: Normal (400). Important: Not all fonts support every font-weight.', 'vt-blogging-pro' )
    );
    $options['site-title-font-size'] = array(
        'id' => 'site-title-font-size',
        'label'   => __( 'Font Size', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 26,
        'description' => __( 'Default: 26', 'vt-blogging-pro' )
    );
    $choices = array(
        'normal' => __( 'Normal', 'vt-blogging-pro' ),
        'italic' => __( 'Italic', 'vt-blogging-pro' )
    );
	$options['site-title-font-style'] = array(
        'id' => 'site-title-font-style',
        'label'   => __( 'Font Style', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'normal',
        'description' => __( 'Default: Normal', 'vt-blogging-pro' )
    );
	
	$choices = array(
        'capitalize' => __( 'Capitalize', 'vt-blogging-pro' ),
        'lowercase' => __( 'Lowercase', 'vt-blogging-pro' ),
        'uppercase' => __( 'Uppercase', 'vt-blogging-pro' )
    );
	$options['site-title-text-transform'] = array(
        'id' => 'site-title-text-transform',
        'label'   => __( 'Text Transform', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'uppercase',
        'description' => __( 'Default: Uppercase', 'vt-blogging-pro' )
    );
	$options['site-title-letter-spacing'] = array(
        'id' => 'site-title-letter-spacing',
        'label'   => __( 'Letter Spacing', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 0,
		'description' => __( 'Default: 0', 'vt-blogging-pro' )
    );
	
	// Site Tagline
    $section = 'typography-section-tagline';
	
	$sections[] = array(
        'id' => $section,
        'title' => __( 'Site Tagline/Description', 'vt-blogging-pro' ),
		'description' => __( 'Do not use <code>px</code> on Font settings <span class="dashicons dashicons-info"></span>', 'vt-blogging-pro' ),
        'priority' => '20',
        'panel' => $panel
    );
	
    $options['site-tagline-font'] = array(
        'id' => 'site-tagline-font',
        'label'   => __( 'Google Font Name', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Open Sans',
        'description' => __( 'Default: Open Sans', 'vt-blogging-pro' )
    );
    $choices = array(
        '100' => __( 'Thin (100)', 'vt-blogging-pro' ),
        '200' => __( 'Extra Light (200)', 'vt-blogging-pro' ),
        '300' => __( 'Light (300)', 'vt-blogging-pro' ),
        '400' => __( 'Normal (400)', 'vt-blogging-pro' ),
        '500' => __( 'Medium (500)', 'vt-blogging-pro' ),
        '600' => __( 'Semi-Bold (600)', 'vt-blogging-pro' ),
        '700' => __( 'Bold (700)', 'vt-blogging-pro' ),
        '800' => __( 'Extra Bold (800)', 'vt-blogging-pro' ),
        '900' => __( 'Ultra Bold (900)', 'vt-blogging-pro' )
    );
	$options['site-tagline-font-weight'] = array(
        'id' => 'site-tagline-font-weight',
        'label'   => __( 'Font Weight', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '400',
        'description' => __( 'Default: Normal (400). Important: Not all fonts support every font-weight.', 'vt-blogging-pro' )
    );
    $options['site-tagline-font-size'] = array(
        'id' => 'site-tagline-font-size',
        'label'   => __( 'Font Size', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 12,
        'description' => __( 'Default: 12', 'vt-blogging-pro' )
    );
    $choices = array(
        'normal' => __( 'Normal', 'vt-blogging-pro' ),
        'italic' => __( 'Italic', 'vt-blogging-pro' )
    );
	$options['site-tagline-font-style'] = array(
        'id' => 'site-tagline-font-style',
        'label'   => __( 'Font Style', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'normal',
        'description' => __( 'Default: Normal', 'vt-blogging-pro' )
    );
	
	$choices = array(
        'capitalize' => __( 'Capitalize', 'vt-blogging-pro' ),
        'lowercase' => __( 'Lowercase', 'vt-blogging-pro' ),
        'uppercase' => __( 'Uppercase', 'vt-blogging-pro' )
    );
	$options['site-tagline-text-transform'] = array(
        'id' => 'site-tagline-text-transform',
        'label'   => __( 'Text Transform', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'uppercase',
        'description' => __( 'Default: Uppercase', 'vt-blogging-pro' )
    );
	$options['site-tagline-letter-spacing'] = array(
        'id' => 'site-tagline-letter-spacing',
        'label'   => __( 'Letter Spacing', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 0,
		'description' => __( 'Default: 0', 'vt-blogging-pro' )
    );
	
	// Site Fonts
    $section = 'typography-section-default';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Site Fonts', 'vt-blogging-pro' ),
		'description' => __( 'Do not use <code>px</code> on Font settings <span class="dashicons dashicons-info"></span>', 'vt-blogging-pro' ),
        'priority' => '21',
        'panel' => $panel
    );

    $options['body-font-name'] = array(
        'id' => 'body-font-name',
        'label'   => __( 'Body Font', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Open Sans',
        'description' => __( 'Default: Open Sans', 'vt-blogging-pro' )
    );
	$options['body-font-size'] = array(
        'id' => 'body-font-size',
        'label'   => __( 'Font Size', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 14,
        'description' => __( 'Default: 14', 'vt-blogging-pro' )
    );
    $options['heading-font'] = array(
        'id' => 'heading-font',
        'label'   => __( 'Heading Font', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Open Sans',
        'description' => __( 'Default: Open Sans', 'vt-blogging-pro' )
    );

	if (class_exists( 'woocommerce' )) {
        $options['wc-product-title-size'] = array(
            'id' => 'wc-product-title-size',
            'label'   => __( 'WooCommerce Product Title Size', 'vt-blogging-pro' ),
            'section' => $section,
            'type'    => 'number',
			'default' => 26,
			'description' => __( 'Default: 26', 'vt-blogging-pro' )
        );
    }


	// Menus
    $section = 'typography-section-menus';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Menus', 'vt-blogging-pro' ),
		'description' => __( 'Do not use <code>px</code> on Font settings <span class="dashicons dashicons-info"></span>', 'vt-blogging-pro' ),
        'priority' => '22',
        'panel' => $panel
    );

    $options['menu-title-font-name'] = array(
        'id' => 'menu-title-font-name',
        'label'   => __( 'Google Font Name', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Open Sans',
        'description' => __( 'Default: Open Sans', 'vt-blogging-pro' )
    );
	
    $choices = array(
        '100' => __( 'Thin (100)', 'vt-blogging-pro' ),
        '200' => __( 'Extra Light (200)', 'vt-blogging-pro' ),
        '300' => __( 'Light (300)', 'vt-blogging-pro' ),
        '400' => __( 'Normal (400)', 'vt-blogging-pro' ),
        '500' => __( 'Medium (500)', 'vt-blogging-pro' ),
        '600' => __( 'Semi-Bold (600)', 'vt-blogging-pro' ),
        '700' => __( 'Bold (700)', 'vt-blogging-pro' ),
        '800' => __( 'Extra Bold (800)', 'vt-blogging-pro' ),
        '900' => __( 'Ultra Bold (900)', 'vt-blogging-pro' )
    );
	$options['menu-title-font-weight'] = array(
        'id' => 'menu-title-font-weight',
        'label'   => __( 'Font Weight', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '400',
        'description' => __( 'Default: Normal (400). Important: Not all fonts support every font-weight.', 'vt-blogging-pro' )
    );
	$options['menu-title-font-size'] = array(
        'id' => 'menu-title-font-size',
        'label'   => __( 'Font Size', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 14,
        'description' => __( 'Default: 14', 'vt-blogging-pro' )
    );
	
    $choices = array(
        'normal' => __( 'Normal', 'vt-blogging-pro' ),
        'italic' => __( 'Italic', 'vt-blogging-pro' )
    );
	$options['menu-title-font-style'] = array(
        'id' => 'menu-title-font-style',
        'label'   => __( 'Font Style', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'normal',
        'description' => __( 'Default: Normal', 'vt-blogging-pro' )
    );
	
	$choices = array(
        'capitalize' => __( 'Capitalize', 'vt-blogging-pro' ),
        'lowercase' => __( 'Lowercase', 'vt-blogging-pro' ),
        'uppercase' => __( 'Uppercase', 'vt-blogging-pro' )
    );
	$options['menu-title-text-transform'] = array(
        'id' => 'menu-title-text-transform',
        'label'   => __( 'Text Transform', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'uppercase',
        'description' => __( 'Default: Uppercase', 'vt-blogging-pro' )
    );
	
	$options['menu-title-letter-spacing'] = array(
        'id' => 'menu-title-letter-spacing',
        'label'   => __( 'Letter Spacing', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 0,
		'description' => __( 'Default: 0', 'vt-blogging-pro' )
    );
	
	// Posts/Pages Title
    $section = 'typography-section-page';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Posts/Pages Title', 'vt-blogging-pro' ),
		'description' => __( 'Do not use <code>px</code> on Font settings <span class="dashicons dashicons-info"></span>', 'vt-blogging-pro' ),
        'priority' => '23',
        'panel' => $panel
    );

    $options['post-title-font-name'] = array(
        'id' => 'post-title-font-name',
        'label'   => __( 'Google Font Name', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Open Sans',
        'description' => __( 'Default: Open Sans', 'vt-blogging-pro' )
    );
	
    $choices = array(
        '100' => __( 'Thin (100)', 'vt-blogging-pro' ),
        '200' => __( 'Extra Light (200)', 'vt-blogging-pro' ),
        '300' => __( 'Light (300)', 'vt-blogging-pro' ),
        '400' => __( 'Normal (400)', 'vt-blogging-pro' ),
        '500' => __( 'Medium (500)', 'vt-blogging-pro' ),
        '600' => __( 'Semi-Bold (600)', 'vt-blogging-pro' ),
        '700' => __( 'Bold (700)', 'vt-blogging-pro' ),
        '800' => __( 'Extra Bold (800)', 'vt-blogging-pro' ),
        '900' => __( 'Ultra Bold (900)', 'vt-blogging-pro' )
    );
	$options['post-title-font-weight'] = array(
        'id' => 'post-title-font-weight',
        'label'   => __( 'Font Weight', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '600',
        'description' => __( 'Default: Semi-Bold (600). Important: Not all fonts support every font-weight.', 'vt-blogging-pro' )
    );
	
	$options['post-title-font-size'] = array(
        'id' => 'post-title-font-size',
        'label'   => __( 'Font Size', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 26,
		'description' => __( 'Default: 26', 'vt-blogging-pro' )
    );
	
    $choices = array(
        'normal' => __( 'Normal', 'vt-blogging-pro' ),
        'italic' => __( 'Italic', 'vt-blogging-pro' )
    );
	$options['post-title-font-style'] = array(
        'id' => 'post-title-font-style',
        'label'   => __( 'Font Style', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'normal',
        'description' => __( 'Default: Normal', 'vt-blogging-pro' )
    );
	
	$choices = array(
        'capitalize' => __( 'Capitalize', 'vt-blogging-pro' ),
        'lowercase' => __( 'Lowercase', 'vt-blogging-pro' ),
        'uppercase' => __( 'Uppercase', 'vt-blogging-pro' )
    );
	$options['post-title-text-transform'] = array(
        'id' => 'post-title-text-transform',
        'label'   => __( 'Text Transform', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'capitalize',
        'description' => __( 'Default: Capitalize', 'vt-blogging-pro' )
    );
	
	$options['post-title-letter-spacing'] = array(
        'id' => 'post-title-letter-spacing',
        'label'   => __( 'Letter Spacing', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 0,
		'description' => __( 'Default: 0', 'vt-blogging-pro' )
    );

	// Widget Title
    $section = 'typography-section-widget';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Widget Title', 'vt-blogging-pro' ),
		'description' => __( 'Do not use <code>px</code> on Font settings <span class="dashicons dashicons-info"></span>', 'vt-blogging-pro' ),
        'priority' => '24',
        'panel' => $panel
    );

    $options['widget-title-font-name'] = array(
        'id' => 'widget-title-font-name',
        'label'   => __( 'Google Font Name', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $font_choices,
        'default' => 'Open Sans',
        'description' => __( 'Default: Open Sans', 'vt-blogging-pro' )
    );
	
    $choices = array(
        '100' => __( 'Thin (100)', 'vt-blogging-pro' ),
        '200' => __( 'Extra Light (200)', 'vt-blogging-pro' ),
        '300' => __( 'Light (300)', 'vt-blogging-pro' ),
        '400' => __( 'Normal (400)', 'vt-blogging-pro' ),
        '500' => __( 'Medium (500)', 'vt-blogging-pro' ),
        '600' => __( 'Semi-Bold (600)', 'vt-blogging-pro' ),
        '700' => __( 'Bold (700)', 'vt-blogging-pro' ),
        '800' => __( 'Extra Bold (800)', 'vt-blogging-pro' ),
        '900' => __( 'Ultra Bold (900)', 'vt-blogging-pro' )
    );
	$options['widget-title-font-weight'] = array(
        'id' => 'widget-title-font-weight',
        'label'   => __( 'Font Weight', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => '600',
        'description' => __( 'Default: Semi-Bold (600). Important: Not all fonts support every font-weight.', 'vt-blogging-pro' )
    );
	
	$options['widget-title-font-size'] = array(
        'id' => 'widget-title-font-size',
        'label'   => __( 'Font Size', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 18,
		'description' => __( 'Default: 18', 'vt-blogging-pro' )
    );
	
    $choices = array(
        'normal' => __( 'Normal', 'vt-blogging-pro' ),
        'italic' => __( 'Italic', 'vt-blogging-pro' )
    );
	$options['widget-title-font-style'] = array(
        'id' => 'widget-title-font-style',
        'label'   => __( 'Font Style', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'normal',
        'description' => __( 'Default: Normal', 'vt-blogging-pro' )
    );
	
	$choices = array(
        'capitalize' => __( 'Capitalize', 'vt-blogging-pro' ),
        'lowercase' => __( 'Lowercase', 'vt-blogging-pro' ),
        'uppercase' => __( 'Uppercase', 'vt-blogging-pro' )
    );
	$options['widget-title-text-transform'] = array(
        'id' => 'widget-title-text-transform',
        'label'   => __( 'Text Transform', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'select',
        'choices' => $choices,
        'default' => 'capitalize',
        'description' => __( 'Default: Capitalize', 'vt-blogging-pro' )
    );
	
	$options['widget-title-letter-spacing'] = array(
        'id' => 'widget-title-letter-spacing',
        'label'   => __( 'Letter Spacing', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'number',
        'default' => 0,
		'description' => __( 'Default: 0', 'vt-blogging-pro' )
    );

	/**-----------------
	 * Theme Text
	 -----------------*/
    $panel = 'vt-panel-text';

    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Override Theme Text', 'vt-blogging-pro' ),
        'priority' => '70'
    );

	// 404
    $section = 'vt-website-section-error-text';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( '404 Error', 'vt-blogging-pro' ),
        'priority' => '30',
        'panel' => $panel
    );

    $options['error-page-heading'] = array(
        'id' => 'error-page-heading',
        'label'   => __( '404 Error Page Heading', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Oops! <span>404</span> Error - Page Not Found', 'vt-blogging-pro')
    );
    $options['error-page-msg'] = array(
        'id' => 'error-page-msg',
        'label'   => __( 'Error 404 Message', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'textarea',
        'default' => __( 'Sorry, but it looks like nothing was found at this location. You may try one of the links below or do a search.', 'vt-blogging-pro')
    );
	
	// Result
    $section = 'vt-website-section-no-result';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Search Form & Result', 'vt-blogging-pro' ),
        'priority' => '40',
        'panel' => $panel
    );
	
    $options['search-text'] = array(
        'id' => 'search-text',
        'label'   => __( 'Search Form', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Search...', 'vt-blogging-pro')
    );
	$options['search-button'] = array(
        'id' => 'search-button',
        'label'   => __( 'Search Button', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Search', 'vt-blogging-pro')
    );
	$options['search-results'] = array(
        'id' => 'search-results',
        'label'   => __( 'Search Results for', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Search Results for', 'vt-blogging-pro')
    );
	
	$options['website-nosearch-head'] = array(
        'id' => 'website-nosearch-head',
        'label'   => __( 'No Search Results Heading', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Nothing Found', 'vt-blogging-pro')
    );
    $options['website-nosearch-msg'] = array(
        'id' => 'website-nosearch-msg',
        'label'   => __( 'No Search Results Message', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'textarea',
        'default' => __( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', 'vt-blogging-pro')
    );
	
	// Continue Reading
    $section = 'vt-website-section-cont-reading';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Continue Reading & Read More', 'vt-blogging-pro' ),
        'priority' => '50',
        'panel' => $panel
    );
    $options['slider-cont-reading'] = array(
        'id' => 'slider-cont-reading',
        'label'   => __( 'Continue Reading', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Continue Reading', 'vt-blogging-pro'),
        'description' => __( 'Appear on the Featured Slider', 'vt-blogging-pro' )
    );
    $options['post-read-more'] = array(
        'id' => 'post-read-more',
        'label'   => __( 'Read More', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Read More', 'vt-blogging-pro'),
        'description' => __( 'Post Excerpt', 'vt-blogging-pro' )
    );

	// Single Post
    $section = 'vt-website-section-single-post';

    $sections[] = array(
        'id' => $section,
        'title' => __( 'Single Post', 'vt-blogging-pro' ),
        'priority' => '60',
        'panel' => $panel
    );
    $options['entry-share'] = array(
        'id' => 'entry-share',
        'label'   => __( 'Share Posts', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'Share :', 'vt-blogging-pro')
    );
    $options['about-author'] = array(
        'id' => 'about-author',
        'label'   => __( 'About the Author', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'text',
        'default' => __( 'About the Author:', 'vt-blogging-pro')
    );	
	
	/**-----------------
	 * Advertisement
	 -----------------*/
    $panel = 'vt-panel-ads';

    $panels[] = array(
        'id' => $panel,
        'title' => __( 'Advertisement', 'vt-blogging-pro' ),
        'priority' => '70'
    );

	// Home Ads
    $section = 'vt-home-ads';
    
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Home', 'vt-blogging-pro' ),
		'description'  => __('Your ad will appear under the Slider. <span class="dashicons dashicons-info"></span>', 'vt-blogging-pro'),
        'priority' => '40',
        'panel' => $panel
    );

    $options['home_ads'] = array(
        'id' => 'home_ads',
        'label'   => __( 'Home Advertisement', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'textarea',
		'sanitize_callback' => ''
    );
	
	// Single Post Ads
    $section = 'vt-section-ads';
	
    $sections[] = array(
        'id' => $section,
        'title' => __( 'Single Post', 'vt-blogging-pro' ),
		'description'  => __('Your ad will appear on the single post. <span class="dashicons dashicons-info"></span>', 'vt-blogging-pro'),
        'priority' => '60',
		'panel' => $panel
    );
	
	$options['vt_blogging_pro_ad_single_before'] = array(
        'id' => 'vt_blogging_pro_ad_single_before',
        'label'   => __( 'Before Content Advertisement', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'textarea',
		'sanitize_callback' => ''
    );

	$options['vt_blogging_pro_ad_single_after'] = array(
        'id' => 'vt_blogging_pro_ad_single_after',
        'label'   => __( 'After Content Advertisement', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'textarea',
		'sanitize_callback' => ''
    );
	
	/**-----------------
	 * Custom Scripts
	 -----------------*/
	$section = 'vt-panel-custom-script';

	$sections[] = array(
		'id' => $section,
        'title'       => __( 'Custom Scripts', 'vt-blogging-pro' ),
		'description' => __( '- Use Header Script (For example: Meta tag verification, Embed Google fonts,etc) <br>They will be added before <code>< /head></code> tag. <br><br> - Use Footer Script (For example: Google analytics, Histats,etc)<br> They will be added before <code>< /body></code> tag', 'vt-blogging-pro' ),
        'priority' => '80'
	);
	
    $options['vt_blogging_pro_header_scripts'] = array(
        'id' => 'vt_blogging_pro_header_scripts',
        'label'   => __( 'Header Scripts', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'textarea'
    );
	$options['vt_blogging_pro_footer_scripts'] = array(
        'id' => 'vt_blogging_pro_footer_scripts',
        'label'   => __( 'Footer Scripts', 'vt-blogging-pro' ),
        'section' => $section,
        'type'    => 'textarea'
    );

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_vt_blogging_pro_options' );


function vt_blogging_pro_register_theme_customizer( $wp_customize ){
	
    // Featured area - Category	
	$wp_customize->add_setting( 'slider-cats', array('default' => '','sanitize_callback' => 'vt_blogging_pro_sanitize_default') );
	$wp_customize->add_control(
		new WP_Customize_Category_Control(
			$wp_customize,
			'slider-cats',
			array(
				'label'		 => __('Select Featured Category', 'vt-blogging-pro'),
				'settings' 	 => 'slider-cats',
				'section'	 => 'featured-area'
			)
		)
	);
	
}
add_action( 'customize_register', 'vt_blogging_pro_register_theme_customizer' );

/**
 * Sanitize functions.
 */
function vt_blogging_pro_sanitize_default( $value ) {
	return $value;
}