<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package VT Blogging Pro
 */

if ( ! function_exists( 'vt_blogging_pro_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function vt_blogging_pro_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}
		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			esc_html_x( '%s', 'post_date', 'vt-blogging-pro' ),
			'<a href="' . esc_url( get_month_link(esc_html(get_the_time('Y')), esc_html(get_the_time('m')) ) ) . '" rel="bookmark">' .$time_string. '</a>'
		);

		echo '<span class="entry-date">' . $posted_on . '</span>'; // WPCS: XSS OK.
		
	}
endif;

// Footer info
if ( ! function_exists( 'vt_blogging_pro_footer' ) ) :
function vt_blogging_pro_footer() {
   $site_link = '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" ><span>' . get_bloginfo( 'name', 'display' ) . '</span></a>';

   $tg_link =  '<a href="' . esc_url("https://volthemes.com/theme/vt-blogging-pro/") . '" target="_blank"><span>'.__( 'VolThemes', 'vt-blogging-pro') .'</span></a>';

   $default_footer_value = 
   /* translators: 1: year, 2: sitename */
   sprintf( __( 'Copyright &copy; %1$s %2$s.', 'vt-blogging-pro' ), date_i18n( 'Y' ), $site_link ).' '.sprintf( __( 'Theme by %2$s', 'vt-blogging-pro' ), 'vt-blogging-pro', $tg_link );
   
   $vt_blogging_pro_footer = '<div class="site-info">' . $default_footer_value . '</div>';
   echo wp_kses_post($vt_blogging_pro_footer);
}
endif;
add_action( 'vt_blogging_pro_footer', 'vt_blogging_pro_footer', 10 );

/**
 * Flush out the transients used in vt_blogging_pro_categorized_blog.
 */
if ( ! function_exists( 'vt_blogging_pro_category_transient_flusher' ) ) :

function vt_blogging_pro_category_transient_flusher() {
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient( 'vt_blogging_pro_categories' );
}
add_action( 'edit_category', 'vt_blogging_pro_category_transient_flusher' );
add_action( 'save_post',     'vt_blogging_pro_category_transient_flusher' );

endif;