<?php
/**
 * Provides a notification to the user everytime our theme is updated.
 *
 * @author Joao Araujo, VolThemes   
 */
 
// Constants for the theme name, folder and remote XML url
define( 'NOTIFIER_THEME_NAME', 'VT Blogging Pro' ); 
define( 'NOTIFIER_THEME_FOLDER_NAME', 'vt-blogging-pro' ); 
define( 'NOTIFIER_XML_FILE', 'https://volthemes.com/api/vt-blogging-pro-notifier.xml' ); // The remote notifier XML file containing the latest version of the theme and changelog
define( 'NOTIFIER_CACHE_INTERVAL', 21600 ); // The time interval for the remote XML cache in the database (21600 seconds = 6 hours)

// Adds an update notification to the WordPress Dashboard menu
function update_notifier_menu() {  
	if (function_exists('simplexml_load_string')) { // Stop if simplexml_load_string function isn't available
	    $xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); // Get the latest remote XML file on our server
		
		// Check theme version
		if(function_exists('wp_get_theme')){
			$theme_data = wp_get_theme(get_option('template'));
			$theme_version = $theme_data->Version;  
		} else {
			$theme_data = wp_get_theme( get_template_directory . '/style.css');
			$theme_version = $theme_data['Version'];
		}

		// Compare current theme version with the remote XML version
		if( (float)$xml->latest > (float)$theme_data['Version']) {
			add_theme_page( NOTIFIER_THEME_NAME . ' Theme Updates', NOTIFIER_THEME_NAME . ' <span class="update-plugins count-1"><span class="update-count">New Updates</span></span>', 'administrator', 'theme-update-notifier', 'update_notifier');
		}
	}	
}
add_action('admin_menu', 'update_notifier_menu');  
// Adds an update notification to the WordPress Admin Bar
function update_notifier_bar_menu() {
	if (function_exists('simplexml_load_string')) { // Stop if simplexml_load_string function isn't available
		global $wp_admin_bar, $wpdb;
	
		// Don't display notification in admin bar if it's disabled or the current user isn't an administrator
		if ( !is_super_admin() || !is_admin_bar_showing() ) 
		return;
		
		// Get the latest remote XML file on our server
		$xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); 
		
		// Check theme version
		if(function_exists('wp_get_theme')){
			$theme_data = wp_get_theme(get_option('template'));
			$theme_version = $theme_data->Version;  
		} else {
			$theme_data = wp_get_theme( get_template_directory . '/style.css');
			$theme_version = $theme_data['Version'];
		}

		// Compare current theme version with the remote XML version
		if( (float)$xml->latest > (float)$theme_data['Version']) {
			$wp_admin_bar->add_menu( array( 'id' => 'update_notifier', 'title' => '<span>' . NOTIFIER_THEME_NAME . ' <span id="ab-updates">New Updates</span></span>', 'href' => get_admin_url() . 'themes.php?page=theme-update-notifier' ) );
		}
	}
}
add_action( 'admin_bar_menu', 'update_notifier_bar_menu', 1000 );

// Get the remote XML file contents and return its data (Version and Changelog)
// Uses the cached version if available and inside the time interval defined
function get_latest_theme_version($interval) {
	$notifier_file_url = NOTIFIER_XML_FILE;	
	$db_cache_field = 'notifier-cache';
	$db_cache_field_last_updated = 'notifier-cache-last-updated';
	$last = get_option( $db_cache_field_last_updated );
	$now = time();
	// check the cache
	if ( !$last || (( $now - $last ) > $interval) ) {
		// cache doesn't exist, or is old, so refresh it
		if( function_exists('curl_init') ) { // if cURL is available, use it...
			$ch = curl_init($notifier_file_url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_HEADER, 0);
			curl_setopt($ch, CURLOPT_TIMEOUT, 10);
			$cache = curl_exec($ch);
			curl_close($ch);
		} else {
			$cache = file_get_contents($notifier_file_url); // ...if not, use the common file_get_contents()
		}
		
		if ($cache) {			
			// we got good results	
			update_option( $db_cache_field, $cache );
			update_option( $db_cache_field_last_updated, time() );
		} 
		// read from the cache file
		$notifier_data = get_option( $db_cache_field );
	}
	else {
		// cache file is fresh enough, so read from it
		$notifier_data = get_option( $db_cache_field );
	}
	
	// if the $xml data was returned as we expected it to.
	if( strpos((string)$notifier_data, '<notifier>') === false ) {
		$notifier_data = '<?xml version="1.0" encoding="UTF-8"?><notifier><latest>2.2</latest><changelog></changelog></notifier>';
	}
	
	// Load the remote XML data into a variable and return it
	$xml= simplexml_load_file(NOTIFIER_XML_FILE) or die("Error: Cannot create object");
	
	//print_r($xml);
	return $xml;
}

// The notifier page
function update_notifier() { 
	$xml = get_latest_theme_version(NOTIFIER_CACHE_INTERVAL); // Get the latest remote XML file on our server
	wp_enqueue_style( 'update-notifier', get_template_directory_uri() . '/inc/update-notifier/update-notifier.css' );
	
		if(function_exists('wp_get_theme')){
			$theme_data = wp_get_theme(get_option('template'));
			$theme_version = $theme_data->Version;  
		} else {
			$theme_data = wp_get_theme( get_template_directory . '/style.css');
			$theme_version = $theme_data['Version'];
		}
		
	?>

	<div class="wrap">
	
		<h2><?php echo NOTIFIER_THEME_NAME ?> Theme Updates</h2>
		<div id="message" class="updated below-h2"><p><strong>There is a new version of the <?php echo NOTIFIER_THEME_NAME; ?> theme available.</strong> You have version <?php echo $theme_data['Version']; ?> installed. Update to version <?php echo $xml->latest; ?>.</p></div>

		<img class="theme-thumbnail" src="<?php echo esc_url( get_template_directory_uri( 'template_url' ) ) . '/screenshot.png'; ?>" />
		
		<div id="instructions">
		    <h3>Update Download and Instructions</h3>
		    
		    <p>To update a theme, login to <a target="_blank" href="https://volthemes.com/member/login/">VolThemes Member Area</a>, you can find the theme package under <strong>Active Resources</strong> section and re-download the theme like you did when you bought it.</p>
			<p>The easiest way to manually update your theme is using <strong>Easy Theme and Plugin Upgrades</strong>. <a target="_blank" href="https://volthemes.com/kb/how-to-update-a-wordpress-theme-manually/">Click here</a> for tutorial.</p>
			<p><strong>Please note:</strong> Make a <strong>backup</strong> of the Theme inside your WordPress installation folder <strong>/wp-content/themes/<?php echo NOTIFIER_THEME_FOLDER_NAME; ?>/</strong></p>
		    <p>If you didn't make any changes to the parent theme files, you are free to overwrite them with the new ones without the risk of losing theme settings, pages, posts, etc, and backwards compatibility is guaranteed.</p>
		</div>
	    
	    <h3 class="title">Changelog</h3>
	    <?php echo $xml->changelog; ?>

	</div>
    
<?php } ?>