<?php
/**
 * Register widget area.
 *
 * @since VT Blogging Pro 1.0
 */
function vt_blogging_pro_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'vt-blogging-pro' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'vt-blogging-pro' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 1', 'vt-blogging-pro' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here to appear in footer column 1.', 'vt-blogging-pro' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 2', 'vt-blogging-pro' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here to appear in footer column 2.', 'vt-blogging-pro' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 3', 'vt-blogging-pro' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here to appear in footer column 3.', 'vt-blogging-pro' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 4', 'vt-blogging-pro' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Add widgets here to appear in footer column 4.', 'vt-blogging-pro' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );
	
	if (class_exists( 'woocommerce' )) {
	  register_sidebar( array(
		'name'          => esc_html__( 'Shop Sidebar', 'vt-blogging-pro' ),
		'id'            => 'sidebar-shop',
		'description'   => esc_html__( 'Add widgets here to appear in your Shop sidebar.', 'vt-blogging-pro' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	  ) );
	}

	/***** Register Widgets *****/
	register_widget('vt_blogging_pro_recent_comments_widget');
	register_widget('vt_blogging_pro_recent_posts_widget');
	register_widget('vt_blogging_pro_most_viewed_widget');
	register_widget('vt_blogging_pro_newsletter_widget');
	register_widget('vt_blogging_pro_popular_widget');
	register_widget('vt_blogging_pro_social_widget');
	register_widget('vt_blogging_pro_random_widget');
	register_widget('vt_blogging_pro_about_widget');
	register_widget('vt_blogging_pro_tab_widget');
	register_widget('vt_blogging_pro_ad_widget');
	register_widget('vt_blogging_pro_fb_like_widget');

}
add_action( 'widgets_init', 'vt_blogging_pro_widgets_init' );

/**
 * Helper function that updates fields in the dashboard form
 *
 * @since VolThemes Widget Pack 1.0
 */
function volthemes_widgets_updated_field_value( $widget_field, $new_field_value ) {

	extract( $widget_field );
	
	// Allow only integers in number fields
	if( $volthemes_widgets_field_type == 'number' ) {
		return absint( $new_field_value );
		
	// Allow some tags in textareas
	} elseif( $volthemes_widgets_field_type == 'textarea' ) {
		// Check if field array specifed allowed tags
		if( !isset( $volthemes_widgets_allowed_tags ) ) {
			// If not, fallback to default tags
			$volthemes_widgets_allowed_tags = '<p><strong><em><a>';
		}
		return strip_tags( $new_field_value, $volthemes_widgets_allowed_tags );
		
	// No allowed tags for all other fields
	} else {
		return strip_tags( $new_field_value );
	}

}

/**
 * Include helper functions that display widget fields in the dashboard
 *
 * @since VolThemes Widget Pack 1.0
 */
get_template_part('inc/widgets/widget-fields');

/***** Include Widgets *****/
get_template_part('inc/widgets/widget-recent-comments');
get_template_part('inc/widgets/widget-recent-posts');
get_template_part('inc/widgets/widget-most-viewed');
get_template_part('inc/widgets/widget-newsletter');
get_template_part('inc/widgets/widget-popular');
get_template_part('inc/widgets/widget-social');
get_template_part('inc/widgets/widget-random');
get_template_part('inc/widgets/widget-about');
get_template_part('inc/widgets/widget-tabs');
get_template_part('inc/widgets/widget-ad');
get_template_part('inc/widgets/widget-fblikebox');

?>