<?php
/**
 * Facebook Like Box.
 *
 * @package VT Blogging Pro
 * Version: 1.0
 */

function load_scripts() {
	wp_enqueue_script( 'fb-likes', get_template_directory_uri() . '/assets/js/fb-like.js', array(), '', true );
}

if( ! class_exists( 'vt_blogging_pro_fb_like_widget' ) ){
	
	class vt_blogging_pro_fb_like_widget extends WP_Widget {
  
		/**
		 * Sets up the widgets.
		 *
		 * @since 1.0.0
		 */
		function __construct() {
			
			/* Widget settings. */
			$widget_ops = array(
				'classname' => 'facebook_like',
				'description' => esc_html__('Display Facebook Like Box', 'vt-blogging-pro')
			);

			parent::__construct(
				'vt-facebook-like-widget',                      // $this->id_base
				__( '[VT] FB Like Box', 'vt-blogging-pro' ),  	// $this->name
				$widget_ops	               			    		// $this->widget_options
			);
			
			// enqueue JS on frontend only if widget is active.
			if ( is_active_widget( false, false, $this->id_base, true ) ) {
				add_action('wp_enqueue_scripts', 'load_scripts');
			}

		}
			
		/**
		 * Outputs the widget based on the arguments input through the widget controls.
		 *
		 * @since 1.0.0
		 */
		function widget($args, $instance) {
		
			extract($args);

			$title = apply_filters('widget_title', $instance['title']);
			$page_url = $instance['page_url'];
			$width = $instance['width'];
			$show_faces = isset($instance['show_faces']) ? 'true' : 'false';
			$show_stream = isset($instance['show_stream']) ? 'true' : 'false';
			$show_header = isset($instance['show_header']) ? 'true' : 'false';
			$hide_cover = isset($instance['show_header']) ? 'false' : 'true';
			$height = '65';
			
			if($show_faces == 'true') {
				$height = '239';
			}
			
			if($show_header == 'true') {
				$height = '264';
			}

			if($show_stream == 'true') {
				$height = '600';
			}
			
			// Output the theme's $before_widget wrapper.
			echo wp_kses_post($before_widget);

			if($title) {
				echo wp_kses_post( $args['before_title'] . $title . $args['after_title'] );
			}
			
			if($page_url): ?>
				<div class="fb-page" data-href="<?php echo esc_url( $page_url ); ?>" data-width="<?php echo esc_attr( $width ); ?>" data-hide-cover="<?php echo esc_attr( $hide_cover ); ?>" data-show-facepile="<?php echo esc_attr( $show_faces ); ?>" data-show-posts="<?php echo esc_attr( $show_stream ); ?>"></div>
			<?php endif;
			
			// Close the theme's widget wrapper.
			echo wp_kses_post($after_widget);
		}
		
		/**
		 * Updates the widget control options for the particular instance of the widget.
		 *
		 * @since 1.0.0
		 */
		function update($new_instance, $old_instance) {
			
			$instance = $old_instance;

			$instance['title'] = strip_tags($new_instance['title']);
			$instance['page_url'] = $new_instance['page_url'];
			$instance['width'] = $new_instance['width'];
			$instance['show_faces'] = $new_instance['show_faces'];
			$instance['show_stream'] = $new_instance['show_stream'];
			$instance['show_header'] = $new_instance['show_header'];
			
			return $instance;
		}

		/**
		 * Displays the widget control options in the Widgets admin screen.
		 *
		 * @since 1.0.0
		 */
		function form($instance) {
			
			// Default value.
			$defaults = array('title' => __('Find us on Facebook', 'vt-blogging-pro' ), 'page_url' => '', 'width' => '300', 'show_faces' => 'on', 'show_stream' => false, 'show_header' => 'on');
			$instance = wp_parse_args((array) $instance, $defaults); ?>
			
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title', 'vt-blogging-pro' ); ?>:</label>
				<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
			</p>
			
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('page_url')); ?>"><?php esc_html_e('Facebook Page URL', 'vt-blogging-pro' ); ?>:</label>
				<input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id('page_url')); ?>" name="<?php echo esc_attr($this->get_field_name('page_url')); ?>" value="<?php echo esc_url( $instance['page_url'] ); ?>" />
			</p>
			
			<p>
				<label for="<?php echo esc_attr($this->get_field_id('width')); ?>"><?php esc_html_e('Width', 'vt-blogging-pro' ); ?>:</label>
				<input type="text" class="widefat" style="width: 45px;" id="<?php echo esc_attr($this->get_field_id('width')); ?>" name="<?php echo esc_attr($this->get_field_name('width')); ?>" value="<?php echo esc_attr( $instance['width'] ); ?>" />
			</p>
			
			<p>
				<input class="checkbox" type="checkbox" <?php checked($instance['show_faces'], 'on'); ?> id="<?php echo esc_attr($this->get_field_id('show_faces')); ?>" name="<?php echo esc_attr($this->get_field_name('show_faces')); ?>" /> 
				<label for="<?php echo esc_attr($this->get_field_id('show_faces')); ?>"><?php esc_html_e('Show faces', 'vt-blogging-pro' ); ?></label>
			</p>
			
			<p>
				<input class="checkbox" type="checkbox" <?php checked($instance['show_stream'], 'on'); ?> id="<?php echo esc_attr($this->get_field_id('show_stream')); ?>" name="<?php echo esc_attr($this->get_field_name('show_stream')); ?>" /> 
				<label for="<?php echo esc_attr($this->get_field_id('show_stream')); ?>"><?php esc_html_e('Show stream', 'vt-blogging-pro' ); ?></label>
			</p>
			
			<p>
				<input class="checkbox" type="checkbox" <?php checked($instance['show_header'], 'on'); ?> id="<?php echo esc_attr($this->get_field_id('show_header')); ?>" name="<?php echo esc_attr($this->get_field_name('show_header')); ?>" /> 
				<label for="<?php echo esc_attr($this->get_field_id('show_header')); ?>"><?php esc_html_e('Show facebook header', 'vt-blogging-pro' ); ?></label>
			</p>
		<?php
		}
	}
} // class vt_blogging_pro_fb_like_widget
?>